<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.upwork.com/fl/rayhan1
 * @since      1.0.0
 *
 * @package    Divi_Contact_Form_Mailchimp_Rc_Extension
 * @subpackage Divi_Contact_Form_Mailchimp_Rc_Extension/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Divi_Contact_Form_Mailchimp_Rc_Extension
 * @subpackage Divi_Contact_Form_Mailchimp_Rc_Extension/admin
 * @author     ReCorp <admin@myrecorp.com>
 */
class Divi_Contact_Form_Mailchimp_Rc_Extension_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	add_action('admin_menu', array($this, 'divi_contact_form_mailchimp') );

	add_action('wp_ajax_divi_contact_for_mailchimp_rc_save_data', array( $this, 'divi_contact_for_mailchimp_rc_save_data'));
	add_action('wp_ajax_nopriv_divi_contact_for_mailchimp_rc_save_data', array( $this, 'divi_contact_for_mailchimp_rc_save_data'));

	add_action('wp_ajax_divi_mc_license_key_auto_update', array( $this, 'divi_mc_license_key_auto_update') );
	add_action('wp_ajax_nopriv_divi_mc_license_key_auto_update', array( $this, 'divi_mc_license_key_auto_update') );


	add_action('wp_ajax_save_dcfme_mailchimp_rc_api', array( $this, 'save_dcfme_mailchimp_rc_api') );
	add_action('wp_ajax_nopriv_save_dcfme_mailchimp_rc_api', array( $this, 'save_dcfme_mailchimp_rc_api') );

	add_action('wp_ajax_dcfme_refresh_mailchimp_rc_lists', array( $this, 'dcfme_refresh_mailchimp_rc_lists'));
	add_action('wp_ajax_nopriv_dcfme_refresh_mailchimp_rc_lists', array( $this, 'dcfme_refresh_mailchimp_rc_lists'));

	add_action('wp_ajax_get_dcfme_mailchimp_rc_list_merge_tags', array( $this, 'get_dcfme_mailchimp_rc_list_merge_tags'));
	add_action('wp_ajax_nopriv_get_dcfme_mailchimp_rc_list_merge_tags', array( $this, 'get_dcfme_mailchimp_rc_list_merge_tags'));		


	add_action('wp_ajax_save_dcfme_mailchimp_rc_cookie', array( $this, 'save_dcfme_mailchimp_rc_cookie'));
	add_action('wp_ajax_nopriv_save_dcfme_mailchimp_rc_cookie', array( $this, 'save_dcfme_mailchimp_rc_cookie'));


		if (is_mfdcf_previous_pro_version_not_expired() || mfdcf_fs()->can_use_premium_code()){
			add_filter("et_contact_page_email_to", array( $this, "filter_dcfme_email_to_use_mailchimp_rc_api") );
		}
	
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Divi_Contact_Form_Mailchimp_Rc_Extension_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Divi_Contact_Form_Mailchimp_Rc_Extension_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		$current_url = "https://".$_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI'];

	if(strpos($current_url, 'divi-contact-form-mailchimp-extension') !== false){
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/divi-contact-form-mailchimp-extension-admin.css', array(), $this->version, 'all' );

		wp_enqueue_style( 'divi_mail_chimp_bootstrap_min', plugin_dir_url( __FILE__ ) . 'css/bootstrap.min.css', array(), $this->version, 'all' );

		wp_enqueue_style( 'dcfme_multi_select', plugin_dir_url( __FILE__ ) . 'css/multi-select.css', array(), $this->version, 'all' );
	}

}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Divi_Contact_Form_Mailchimp_Rc_Extension_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Divi_Contact_Form_Mailchimp_Rc_Extension_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
	$current_url = "https://".$_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI'];

		if(strpos($current_url, 'divi-contact-form-mailchimp-extension') !== false){
			wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/divi-contact-form-mailchimp-extension-admin.js', array( 'jquery', 'bootstrap-notify', 'velocity-ui-min'), $this->version, false );

			wp_enqueue_script( 'bootstrap-notify', plugin_dir_url( __FILE__ ) . 'js/bootstrap-notify.js', array( 'jquery', 'bootstrap-min' ), $this->version, false );

			wp_enqueue_script( 'bootstrap-min', plugin_dir_url( __FILE__ ) . 'js/bootstrap.min.js', array( 'jquery' ), $this->version, false );

			wp_enqueue_script( 'velocity-min', plugin_dir_url( __FILE__ ) . 'js/velocity.min.js', array( 'jquery' ), $this->version, false );

			wp_enqueue_script( 'velocity-ui-min', plugin_dir_url( __FILE__ ) . 'js/velocity-ui.min.js', array( 'jquery', 'velocity-min' ), $this->version, false );

			wp_enqueue_script( 'multi-select-dcfme', plugin_dir_url( __FILE__ ) . 'js/multi-select.js', array( 'bootstrap-min' ), $this->version, false );

			wp_add_inline_script($this->plugin_name, '
				/* <!\[CDATA\[ */
					var dcfme = {"theme_url":"'.  get_stylesheet_directory_uri() .'",
						"members_url":"'.  get_home_url() . '/members' .'",
						"home_url":"'.  get_home_url() .'",
						"ajax_url":"'. get_admin_url() . 'admin-ajax.php' . '",
						"nonce": "'.wp_create_nonce( "recorp_nonce" ).'",
						};
				/* \]\]> */
			');

		}
	}


	public function divi_contact_form_mailchimp(){

		add_options_page(
			'Divi Contact Form Mailchimp Extension',
			__('Mailchimp for Divi Contact Form', 'different-menus'),
			'manage_options',
			'divi-contact-form-mailchimp-extension',
			array(
				$this,
				'load_admin_dependencies'
			)
		);
	}

	public function load_admin_dependencies(){
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/divi-contact-form-mailchimp-extension-admin-display.php';

	}


	public function divi_contact_for_mailchimp_rc_save_data(){
		$data = isset($_POST['mc_table']) ? $_POST['mc_table'] : "";
		$subscribe_text = isset($_POST['subscribe_text']) ? $_POST['subscribe_text'] : "";

		update_option('dcfme_subscribe_text', esc_html($subscribe_text));
		

		if (!empty($data)) {
			update_option('recorp_divi_mailchimp', $data);
		}
	
		die();
	}



public function divi_mc_license_key_auto_update(){
	$license_key = $_POST["license_key"];
	$expire = $license_expire = ($_POST["expire"]/*/1000*/);

	$data = array(
		'license_key' => $license_key, 
		'expire' => $expire
	);

	$data = serialize($data);

/*	if (get_option('dcme_licanse_key', 'empty') == "empty") {
		add_option("dcme_licanse_key", $data);
	} else {
		update_option("dcme_licanse_key", $data);
	}*/
	
	update_option("dcfme_license_key", $data);

	header('Content-Type: application/json');

		if(!empty($license_expire)){
				$license_expire = date('d-m-Y',strtotime(date("d-m-Y", $license_expire) ));

				$unix_expire = strtotime($license_expire);
			$now = new DateTime();
			$future_date = new DateTime($license_expire);

			$interval = $future_date->diff($now);

			$license_expire .= " " . $interval->format("(%a days remaining)");
			
			if( $now > $unix_expire ){
				$license_expire = "expired";
			}
		}

	echo json_encode(array('key_status' => 'valid', 'expire' => $license_expire));
	wp_die();
}

function save_dcfme_mailchimp_rc_api(){
	$api_key = $_POST['key'];

	// Query String Perameters are here
	// for more reference please vizit http://developer.mailchimp.com/documentation/mailchimp/reference/lists/
	$data = array(
	    'fields' => 'lists', // total_items, _links

	);

	$dc = substr($api_key,strpos($api_key,'-')+1);
	$url = 'https://' . $dc . '.api.mailchimp.com/3.0/lists/';

	$response = $this->connect_mailchimp_rc_account($url, 'GET', $api_key, $data);

	$result = json_decode($response);

	if( isset($result->lists) && !empty($result->lists) ) {

		$api = array(
			'api_key' => $api_key,
			'status' => 'valid'
		);

		update_option('dcfme_mailchimp_rc_api', $api);

		$lists = array();
	    foreach( $result->lists as $list ){

	        $list2 = array();
	        $list2['id'] = $list->id;
	        $list2['name'] = $list->name;
	        $list2['member_count'] = $list->stats->member_count;

	        $lists[] = $list2;

	    }
	 
	 update_option('dcfme_mailchimp_rc_lists', $lists);

	 echo json_encode( array('status' => 'connected') );

	} elseif ( is_int( $result->status ) ) { // full error glossary is here http://developer.mailchimp.com/documentation/mailchimp/guides/error-glossary/
	    echo json_encode( array('status' => 'invalid') );
	}


	die();

}


private function connect_mailchimp_rc_account( $url, $request_type, $api_key, $data = array() ) {
    if( $request_type == 'GET' )
        $url .= '?' . http_build_query($data);
 
    $mch = curl_init();
    $headers = array(
        'Content-Type: application/json',
        'Authorization: Basic '.base64_encode( 'user:'. $api_key )
    );
    curl_setopt($mch, CURLOPT_URL, $url );
    curl_setopt($mch, CURLOPT_HTTPHEADER, $headers);
    //curl_setopt($mch, CURLOPT_USERAGENT, 'PHP-MCAPI/2.0');
    curl_setopt($mch, CURLOPT_RETURNTRANSFER, true); // do not echo the result, write it into variable
    curl_setopt($mch, CURLOPT_CUSTOMREQUEST, $request_type); // according to MailChimp API: POST/GET/PATCH/PUT/DELETE
    curl_setopt($mch, CURLOPT_TIMEOUT, 10);
    curl_setopt($mch, CURLOPT_SSL_VERIFYPEER, false); // certificate verification for TLS/SSL connection
 
    if( $request_type != 'GET' ) {
        curl_setopt($mch, CURLOPT_POST, true);
        curl_setopt($mch, CURLOPT_POSTFIELDS, json_encode($data) ); // send data in json
    }
 
    return curl_exec($mch);
}

public function dcfme_refresh_mailchimp_rc_lists(){
	$mailchimp = get_option('dcfme_mailchimp_rc_api');

	if ($mailchimp['status'] == 'valid') {
		
		$api_key = $mailchimp['api_key'];

		$data = array(
	    	'fields' => 'lists', // total_items, _links
		);

	$dc = substr($api_key,strpos($api_key,'-')+1);
	$url = 'https://' . $dc . '.api.mailchimp.com/3.0/lists/';

	$response = $this->connect_mailchimp_rc_account($url, 'GET', $api_key, $data);

	$result = json_decode($response);

	if( isset($result->lists) && !empty($result->lists) ) {

		$api = array(
			'api_key' => $api_key,
			'status' => 'valid'
		);

		update_option('dcfme_mailchimp_rc_api', $api);

		$lists = array();
	    foreach( $result->lists as $list ){

	        $list2 = array();
	        $list2['id'] = $list->id;
	        $list2['name'] = $list->name;
	        $list2['member_count'] = $list->stats->member_count;

	        $lists[] = $list2;

	    }
	 
	 update_option('dcfme_mailchimp_rc_lists', $lists);

	}

	}
}

public function get_dcfme_mailchimp_rc_list_merge_tags(){
	$list_id = $_POST['list_id'];

	$mailchimp = get_option('dcfme_mailchimp_rc_api');

	if ($mailchimp['status'] == 'valid') {
		
		$api_key = $mailchimp['api_key'];
	 
		// Query String Perameters are here
		// for more reference please vizit http://developer.mailchimp.com/documentation/mailchimp/reference/lists/
		$data = array(
		    'fields' => 'merge_fields', // total_items, _links

		);
		 
		$url = 'https://' . substr($api_key,strpos($api_key,'-')+1) . '.api.mailchimp.com/3.0/lists/'.$list_id.'/merge-fields';


		$merge_fields = json_decode( $this->connect_mailchimp_rc_account( $url, 'GET', $api_key, $data) );


		$merged = '<h3 style="font-size: 1.3em;font-weight: bold;margin: 1em 0;">Merge fields</h3>
		<table class="widefat striped">
		    <thead>
		        <tr>
		            <th>Name</th>
		            <th>Tag</th>
		            <th>Type</th>
		        </tr>
		    </thead>
		    <tbody>';

	if(isset($merge_fields->merge_fields) && !empty($merge_fields->merge_fields)){

		foreach ($merge_fields->merge_fields as $key => $merge_field) {
		    $name = $merge_field->name;
		    $tag = $merge_field->tag;
		    $type = $merge_field->type;

		    $required = ($type == "email") ? '<span class="red">*</span>' : "";
		    $bday_pattern = ($type == "birthday") ? "({$merge_field->options->date_format})" : "";

		    $merged .= "<tr>
		                    <td>{$name} {$required}</td>
		                    <td><code>{$tag}</code></td>
		                    <td>{$type} {$bday_pattern} </td>
		                </tr>";
		}
	}


		$merged .= "
		            </tbody>
		        </table>";

		echo $merged;
	} else {
		echo ""; }

		die();
}

public function save_dcfme_mailchimp_rc_cookie(){

	ob_start();

$cookie_name = "dcfmec";
	$cookie_value = "yy";
	//setcookie($cookie_name, $cookie_value, time() + (86400 * 30), "/");


ob_end_flush();
	//echo $_COOKIE[$cookie_name];
	

	die();
}

	private function insert_email_to_mailchimp(){

		if( ( $this->get_user_permission_status() == "enable" && isset($_POST['add_to_mailing_list'])) || $this->get_user_permission_status() == "disable" ){

			if (isset($_POST['et_pb_contact_email_0'])) {
				$email = $_POST['et_pb_contact_email_0'];
			}
			elseif(isset($_POST['et_pb_contact_email_1'])){
				$email = $_POST['et_pb_contact_email_1'];
			}
			else {
				$email = "";
			}

			
			if (isset($_POST['et_pb_contact_name_0'])) {
				$first_name = $_POST['et_pb_contact_name_0'];
			}
			elseif(isset($_POST['et_pb_contact_name_1'])){
				$first_name = $_POST['et_pb_contact_name_1'];
			}
			elseif (isset($_POST['et_pb_contact_first_name_0'])) {
				$first_name = $_POST['et_pb_contact_first_name_0'];
			}
			elseif(isset($_POST['et_pb_contact_first_name_1'])){
				$first_name = $_POST['et_pb_contact_first_name_1'];
			}
			else {
				$first_name = "";
			}

			if (isset($_POST['et_pb_contact_last_name_0'])) {
				$last_name = $_POST['et_pb_contact_last_name_0'];
			}
			elseif(isset($_POST['et_pb_contact_last_name_1'])){
				$last_name = $_POST['et_pb_contact_last_name_1'];
			}
			else {
				$last_name = "";
			}

			if (isset($_POST['et_pb_contact_birth_day_0'])) {
				$bday = $_POST['et_pb_contact_birth_day_0'];
			}
			elseif(isset($_POST['et_pb_contact_birth_day_1'])){
				$bday = $_POST['et_pb_contact_birth_day_1'];
			}
			else {
				$bday = "";
			}

			if (isset($_POST['et_pb_contact_address_0'])) {
				$address = $_POST['et_pb_contact_address_0'];
			}
			elseif(isset($_POST['et_pb_contact_address_1'])){
				$address = $_POST['et_pb_contact_address_1'];
			}
			else {
				$address = "";
			}
			

			if (isset($_POST['et_pb_contact_phone_0'])) {
				$phone = $_POST['et_pb_contact_phone_0'];
			}
			elseif(isset($_POST['et_pb_contact_phone_1'])){
				$phone = $_POST['et_pb_contact_phone_1'];
			}
			else {
				$phone = "";
			}

			$merge_fields = array();
			if (!empty($_POST)) {
			    foreach ($_POST as $key => $value) {
			        $merged = (!empty($this->get_string_between($key, 'et_pb_contact_', '_0'))) ? $this->get_string_between($key, 'et_pb_contact_', '_0') : $this->get_string_between($key, 'et_pb_contact_', '_1');

			        $merged = strtoupper($merged);

			        if (!empty($merged) && $merged !== "MESSAGE" &&  $merged !== "CAPTCHA" &&  $merged !== "EMAIL_FIELDS" && $merged !== "EMAIL_HIDDEN_FIELDS"  && $merged !== "EMAIL" ) {
			            $merge_fields[$merged] = $value;
			        }
			    }
			}

			$merge_fields['FNAME'] = $first_name;
			$merge_fields['LNAME'] = $last_name;

			$data = array(
				'email_address' => $email,
				'status' => 'subscribed',
				'merge_fields' => $merge_fields
			);


				$mailchimp = get_option('dcfme_mailchimp_rc_api');

				if ( isset($mailchimp['status']) && $mailchimp['status'] == 'valid') {

					$_wp_http_referer = isset($_POST['_wp_http_referer']) ? $_POST['_wp_http_referer'] : "";
					$post_id = url_to_postid($_wp_http_referer);


					$lists = $this->get_dcfme_mailchimp_rc_list_by_post_id($post_id);

					if ( !empty($_wp_http_referer) && !empty($lists)) {
						foreach ($lists as $key => $list_id) {
							$api_key = $mailchimp['api_key'];

						  
							$url = 'https://' . substr($api_key,strpos($api_key,'-')+1) . '.api.mailchimp.com/3.0/lists/'.$list_id.'/members/';

							update_option('ttt3', $data);
								$this->connect_mailchimp_rc_account( $url, 'POST', $api_key, $data);
						}

					}
					
					
				}

			}
	}

	public function filter_dcfme_email_to_use_mailchimp_rc_api($email){
		$this->insert_email_to_mailchimp();
		return $email;
	}

	private function get_dcfme_mailchimp_rc_list_by_post_id($post_id){
	    $datas = get_option('recorp_divi_mailchimp');

	    if (!empty($datas)) {
	    	$datas = stripslashes($datas);
			$datas = json_decode($datas);

			if (!empty($datas->form_data)) {
				foreach ( $datas->form_data as $key => $value) {
			        if ($value->post_id == $post_id) {
			            return $value->list_id;
			            break;
			        }
			    }
			}
		    
		}

	}

	private function get_string_between($string, $start, $end){
	    $string = ' ' . $string;
	    $ini = strpos($string, $start);
	    if ($ini == 0) return '';
	    $ini += strlen($start);
	    $len = strpos($string, $end, $ini) - $ini;
	    return substr($string, $ini, $len);
	}

	public function get_user_permission_status(){
		$datas = get_option('recorp_divi_mailchimp');

		if (!empty($datas)) {

			$datas = stripslashes($datas);
			$datas = json_decode($datas);

			return $datas->settings->user_permission;
			
		}
	}
}


function get_dcfme_recorp_mc_by_id($mc_id=0, $need="", $list_id = ""){
	$datas = get_option('recorp_divi_mailchimp');

	if (!empty($datas)) {

		$datas = stripslashes($datas);
		$datas = json_decode($datas);

		if (isset($datas->form_data)) {
				
			foreach ($datas->form_data as $key => $data) {

				$post_id = $data->post_id;
				$mc_lists = $data->list_id;
				$status = $data->form_status;

				if ($mc_id == $post_id) {
					if ($need == 'lists') {

						$is = "";
						foreach ($mc_lists as $key => $value2) {
							if ( $value2 == $list_id) {
								$is .= "true";

								break;
							}
						}

						return $is;
						
					}
					if ($need == 'status') {
						return $status;
					}
				}

				if (!empty($data->settings->user_permission)) {
					$user_permission = $data->settings->user_permission;
					if ($need == 'user_permission') {
						return $user_permission;
					}
				}

			}
		}

	}
}