<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.upwork.com/fl/rayhan1
 * @since             1.0.0
 * @package           Divi_Contact_Form_Mailchimp_Rc_Extension
 *
 * @wordpress-plugin
 * Plugin Name:       Mailchimp for Divi Contact Form
 * Plugin URI:        https://myrecorp.com/plugins/divi-contact-form-mailchimp-extension
 * Description:       This is a short description of what the plugin does. It's displayed in the WordPress admin area.
 * Version:           2.5.2
 * Author:            ReCorp
 * Author URI:        https://www.upwork.com/fl/rayhan1
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       dcfme
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'DIVI_CONTACT_FORM_MAILCHIMP_EXTENSION_VERSION', '2.5.2' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-divi-contact-form-mailchimp-extension-activator.php
 */
function activate_divi_contact_form_mailchimp_rc_extension() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-divi-contact-form-mailchimp-extension-activator.php';
	Divi_Contact_Form_Mailchimp_Rc_Extension_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-divi-contact-form-mailchimp-extension-deactivator.php
 */
function deactivate_divi_contact_form_mailchimp_rc_extension() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-divi-contact-form-mailchimp-extension-deactivator.php';
	Divi_Contact_Form_Mailchimp_Rc_Extension_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_divi_contact_form_mailchimp_rc_extension' );
register_deactivation_hook( __FILE__, 'deactivate_divi_contact_form_mailchimp_rc_extension' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
//Requiring freemius sdk
require plugin_dir_path( __FILE__ ) . 'freemius.php';
require plugin_dir_path( __FILE__ ) . 'includes/class-divi-contact-form-mailchimp-extension.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_divi_contact_form_mailchimp_rc_extension() {

	$plugin = new Divi_Contact_Form_Mailchimp_Rc_Extension();
	$plugin->run();

}
run_divi_contact_form_mailchimp_rc_extension();


/*Redirect to plugin's settings page when plugin will active*/
register_activation_hook(__FILE__, 'divi_mailchimp_rc_activation_redirect');
add_action('admin_init', 'divi_mailchimp_rc_redirect_to_settings_page');


function divi_mailchimp_rc_activation_redirect() {
    add_option('divi_contact_form_mailchimp_rc_extension_redirect', true);
}


function divi_mailchimp_rc_redirect_to_settings_page() {
    if (get_option('divi_contact_form_mailchimp_rc_extension_redirect', false)) {
        delete_option('divi_contact_form_mailchimp_rc_extension_redirect');
         exit( wp_redirect("options-general.php?page=divi-contact-form-mailchimp-extension&welcome=true") );
    }
}
/*End plugin redirect*/


if(mfdcf_fs()->can_use_premium_code()||is_mfdcf_previous_pro_version_not_expired()){
    
    require 'plugin-updates/plugin-update-checker.php';
    $DifferentMenuUpdateChecker = PucFactory::buildUpdateChecker(
        'https://myrecorp.com/plugin-auto-update/divi_contact_form_mailchimp_extension_auto_update.php',
        __FILE__,
        'mailchimp-for-divi-contact-form'
    );
    //Here's how you can add query arguments to the URL.
    function divi_contact_form_mailchimp_rc_extension($query){

        if(mfdcf_fs()->can_use_premium_code()){
            $query['secret'] = "freemius_version";
        } elseif(!empty(get_option("dcfme_license_key"))){
            $query['secret'] = unserialize(get_option("dcme_licanse_key"))['license_key'];
        } else {
            $query['secret'] = "";
        }

        return $query;
    }
    $DifferentMenuUpdateChecker->addQueryArgFilter('divi_contact_form_mailchimp_rc_extension');
}



if (!is_mfdcf_previous_pro_version_not_expired()&&!mfdcf_fs()->can_use_premium_code()) {
//Set expired message
    function if_divi_contact_form_mailchimp_rc_extension_is_not_activated() {
        ?>
        <div class="error notice">
            <p><?php _e( '<strong>Divi Contact Form Mailchimp Extension </strong> is not activated with license key. Please activate the license key to activate the plugin. <a href="options-general.php?page=divi-contact-form-mailchimp-extension&license=true">Click here</a> to activate.', 'my_plugin_textdomain' ); ?></p>
        </div>
        <?php
    }
    add_action( 'admin_notices', 'if_divi_contact_form_mailchimp_rc_extension_is_not_activated' );

}

mfdcf_fs()->add_action('after_uninstall', 'mfdcf_fs_uninstall_cleanup');